@@ -112,8 +112,8 @@ class Calltracking extends \FreePBX_Helpers implements \BMO
      */
     private function eraseConfigs()
     {
-        $clientNameList = explode(',', $this->astman->database_get('zruchnaio/calltracking', 'clients'));
-        $didNameList = explode(',', $this->astman->database_get('zruchnaio/calltracking', 'dids'));
+        $clientNameList = $this->getClientsConfiguration();
+        $didNameList = $this->getDidsConfiguration();
 
         foreach ($clientNameList as $clientName) {
             $this->astman->database_del($clientName, 'key');
@@ -150,8 +150,8 @@ class Calltracking extends \FreePBX_Helpers implements \BMO
         }
 
         $this->astman->database_put('zruchnaio/calltracking', 'configured', gmdate(\DATE_ATOM));
-        $this->astman->database_put('zruchnaio/calltracking', 'clients', implode(',', $clientNameList));
-        $this->astman->database_put('zruchnaio/calltracking', 'dids', implode(',', array_keys($didNameSet)));
+        $this->putSequenceDatabaseValue('zruchnaio/calltracking/clients', $clientNameList);
+        $this->putSequenceDatabaseValue('zruchnaio/calltracking/dids', $didNameSet);
     }
 
     /**
@@ -163,8 +163,8 @@ class Calltracking extends \FreePBX_Helpers implements \BMO
             return array();
         }
 
-        $clientNameList = explode(',', $this->astman->database_get('zruchnaio/calltracking', 'clients'));
-        $didNameList = explode(',', $this->astman->database_get('zruchnaio/calltracking', 'dids'));
+        $clientNameList = $this->getClientsConfiguration();
+        $didNameList = $this->getClientsConfiguration();
 
         $clientDidsMap = array();
         foreach ($didNameList as $didName) {
@@ -194,11 +194,88 @@ class Calltracking extends \FreePBX_Helpers implements \BMO
     private function isConfigured()
     {
         return !empty($this->astman->database_get('zruchnaio/calltracking', 'configured'))
-            && !empty($this->astman->database_get('zruchnaio/calltracking', 'clients'))
-            && !empty($this->astman->database_get('zruchnaio/calltracking', 'dids'))
+            && !empty($this->getClientsConfiguration())
+            && !empty($this->getDidsConfiguration())
         ;
     }
 
+    /**
+     * @deprecated use {@see self::getSequenceDatabaseValue()} method with "zruchnaio/calltracking/clients" argument instead
+     *
+     * @return string[]
+     */
+    private function getClientsConfiguration()
+    {
+        if ($clients = $this->getSequenceDatabaseValue('zruchnaio/calltracking/clients')) {
+            return $clients;
+        }
+
+        // deprecated storage
+        if ($clients = $this->astman->database_get('zruchnaio/calltracking', 'clients')) {
+            \trigger_error('The "/zruchnaio/calltracking/clients" storage is deprecated, resave configuration to store it as "/zruchnaio/calltracking/clients/######"', \E_USER_DEPRECATED);
+
+            return explode(',', $clients);
+        }
+
+        return [];
+    }
+
+    /**
+     * @deprecated use {@see self::getSequenceDatabaseValue()} method with "zruchnaio/calltracking/dids" argument instead
+     *
+     * @return string[]
+     */
+    private function getDidsConfiguration()
+    {
+        if ($dids = $this->getSequenceDatabaseValue('zruchnaio/calltracking/dids')) {
+            return $dids;
+        }
+
+        // deprecated storage
+        if ($dids = $this->astman->database_get('zruchnaio/calltracking', 'dids')) {
+            \trigger_error('The "/zruchnaio/calltracking/dids" storage is deprecated, resave configuration to store it as "/zruchnaio/calltracking/dids/######"', \E_USER_DEPRECATED);
+
+            return explode(',', $dids);
+        }
+
+        return [];
+    }
+
+    /**
+     * @param string $family
+     *
+     * @return string[]
+     */
+    protected function getSequenceDatabaseValue($family)
+    {
+        $values = $this->astman->database_show($family);
+
+        if (!$values) {
+            return [];
+        }
+
+        ksort($values, SORT_STRING);
+
+        return array_values($values);
+    }
+
+    /**
+     * @param string   $family
+     * @param string[] $values
+     *
+     * @return void
+     */
+    protected function putSequenceDatabaseValue($family, array $values)
+    {
+        /** @var int<0, max> $idx */
+        $idx = 0;
+
+        foreach ($values as $value) {
+            $key = sprintf('%06d', ++$idx);
+            $this->astman->database_put($family, $key, $value);
+        }
+    }
+
     private function addAgiBinFile($filename)
     {
         global $amp_conf;
